==> openvdb-9.0.0-9.1-armv7h.pkg.tar.xz: usr/share/doc/OpenVDB/html/search/defines_3.js <==
var searchData=
[
  ['checkptr_0',['checkPtr',['../HostBuffer_8h.html#aff2830fced928188855df8b9366e031f',1,'checkPtr():&#160;HostBuffer.h'],['../CudaDeviceBuffer_8h.html#aff2830fced928188855df8b9366e031f',1,'checkPtr():&#160;CudaDeviceBuffer.h']]],
  ['cnanovdb_5falignment_5fpadding_1',['CNANOVDB_ALIGNMENT_PADDING',['../CNanoVDB_8h.html#a8c55cbbc285bda0a4fa67c1c328e7e3e',1,'CNanoVDB.h']]],
  ['cnanovdb_5fdata_5falignment_2',['CNANOVDB_DATA_ALIGNMENT',['../CNanoVDB_8h.html#aa37d5ded20466779f1a10138545546bc',1,'CNanoVDB.h']]],
  ['cnanovdb_5fglobal_3',['CNANOVDB_GLOBAL',['../CNanoVDB_8h.html#a7f096c15911abf186f73c60507f88027',1,'CNanoVDB.h']]],
  ['countonb2_4',['COUNTONB2',['../NodeMasks_8h.html#a1bbb08f4691eb731a4157b93548f6579',1,'NodeMasks.h']]],
  ['countonb4_5',['COUNTONB4',['../NodeMasks_8h.html#a5315b2bf8de14036c7ac00f94bfb4a32',1,'NodeMasks.h']]],
  ['countonb6_6',['COUNTONB6',['../NodeMasks_8h.html#a0926c45aca92902315e17981789b8824',1,'NodeMasks.h']]],
  ['create_5faccessor_7',['CREATE_ACCESSOR',['../CNanoVDB_8h.html#a1217f5c9e6611deb3136612857d2fda2',1,'CNanoVDB.h']]],
  ['create_5fgridtype_8',['CREATE_GRIDTYPE',['../CNanoVDB_8h.html#adbbbcfc003739035919fdd6cb09d050b',1,'CNanoVDB.h']]],
  ['create_5finternal_5fnode_9',['CREATE_INTERNAL_NODE',['../CNanoVDB_8h.html#a3c43455e405a28bf30394c2008b70b32',1,'CNanoVDB.h']]],
  ['create_5finternal_5fnode_5fint_10',['CREATE_INTERNAL_NODE_int',['../CNanoVDB_8h.html#a3e12a4697c57caa38cf5ab3fbb27c390',1,'CNanoVDB.h']]],
  ['create_5fleaf_5fnode_11',['CREATE_LEAF_NODE',['../CNanoVDB_8h.html#a8dabf637e3ee237af7e009099f5ce824',1,'CNanoVDB.h']]],
  ['create_5fleaf_5fnode_5fint_12',['CREATE_LEAF_NODE_int',['../CNanoVDB_8h.html#a47bd840ced7fd156ed73346b118e3c00',1,'CNanoVDB.h']]],
  ['create_5flerpsimple_13',['CREATE_LERPSIMPLE',['../CSampleFromVoxels_8h.html#a9687f55bd4665cb1b9574ea31a0e8327',1,'CSampleFromVoxels.h']]],
  ['create_5frootdata_14',['CREATE_ROOTDATA',['../CNanoVDB_8h.html#aff94f0347d1f83f3188f47eb80378840',1,'CNanoVDB.h']]],
  ['create_5fsample_15',['CREATE_SAMPLE',['../CSampleFromVoxels_8h.html#a32c37274211ce9ce06e746655d8bb833',1,'CSampleFromVoxels.h']]],
  ['create_5fstencil_16',['CREATE_STENCIL',['../CSampleFromVoxels_8h.html#af44e910a01a2e0dcdac8bab426ed3365',1,'CSampleFromVoxels.h']]],
  ['create_5ftileentry_17',['CREATE_TILEENTRY',['../CNanoVDB_8h.html#a9e6f602fbea00a179a9c49ea97dfeebd',1,'CNanoVDB.h']]],
  ['cudacheck_18',['cudaCheck',['../CudaDeviceBuffer_8h.html#a93e6bf7c8996268aa9a2740d6f1de76d',1,'CudaDeviceBuffer.h']]]
];

==> openvdb-10.0.1-5-armv7h.pkg.tar.xz: usr/share/doc/OpenVDB/html/search/defines_3.js <==
var searchData=
[
  ['checkptr_0',['checkptr',['../HostBuffer_8h.html#aff2830fced928188855df8b9366e031f',1,'checkPtr:&#160;HostBuffer.h'],['../CudaDeviceBuffer_8h.html#aff2830fced928188855df8b9366e031f',1,'checkPtr:&#160;CudaDeviceBuffer.h']]],
  ['cnanovdb_5falignment_5fpadding_1',['CNANOVDB_ALIGNMENT_PADDING',['../CNanoVDB_8h.html#a8c55cbbc285bda0a4fa67c1c328e7e3e',1,'CNanoVDB.h']]],
  ['cnanovdb_5fdata_5falignment_2',['CNANOVDB_DATA_ALIGNMENT',['../CNanoVDB_8h.html#aa37d5ded20466779f1a10138545546bc',1,'CNanoVDB.h']]],
  ['cnanovdb_5fglobal_3',['CNANOVDB_GLOBAL',['../CNanoVDB_8h.html#a7f096c15911abf186f73c60507f88027',1,'CNanoVDB.h']]],
  ['countonb2_4',['COUNTONB2',['../NodeMasks_8h.html#a1bbb08f4691eb731a4157b93548f6579',1,'NodeMasks.h']]],
  ['countonb4_5',['COUNTONB4',['../NodeMasks_8h.html#a5315b2bf8de14036c7ac00f94bfb4a32',1,'NodeMasks.h']]],
  ['countonb6_6',['COUNTONB6',['../NodeMasks_8h.html#a0926c45aca92902315e17981789b8824',1,'NodeMasks.h']]],
  ['create_5faccessor_7',['CREATE_ACCESSOR',['../CNanoVDB_8h.html#a1217f5c9e6611deb3136612857d2fda2',1,'CNanoVDB.h']]],
  ['create_5fgridtype_8',['CREATE_GRIDTYPE',['../CNanoVDB_8h.html#adbbbcfc003739035919fdd6cb09d050b',1,'CNanoVDB.h']]],
  ['create_5finternal_5fnode_9',['CREATE_INTERNAL_NODE',['../CNanoVDB_8h.html#a3c43455e405a28bf30394c2008b70b32',1,'CNanoVDB.h']]],
  ['create_5finternal_5fnode_5fint_10',['CREATE_INTERNAL_NODE_int',['../CNanoVDB_8h.html#a3e12a4697c57caa38cf5ab3fbb27c390',1,'CNanoVDB.h']]],
  ['create_5fleaf_5fnode_11',['CREATE_LEAF_NODE',['../CNanoVDB_8h.html#a8dabf637e3ee237af7e009099f5ce824',1,'CNanoVDB.h']]],
  ['create_5fleaf_5fnode_5fint_12',['CREATE_LEAF_NODE_int',['../CNanoVDB_8h.html#a47bd840ced7fd156ed73346b118e3c00',1,'CNanoVDB.h']]],
  ['create_5flerpsimple_13',['CREATE_LERPSIMPLE',['../CSampleFromVoxels_8h.html#a9687f55bd4665cb1b9574ea31a0e8327',1,'CSampleFromVoxels.h']]],
  ['create_5frootdata_14',['CREATE_ROOTDATA',['../CNanoVDB_8h.html#aff94f0347d1f83f3188f47eb80378840',1,'CNanoVDB.h']]],
  ['create_5fsample_15',['CREATE_SAMPLE',['../CSampleFromVoxels_8h.html#a32c37274211ce9ce06e746655d8bb833',1,'CSampleFromVoxels.h']]],
  ['create_5fstencil_16',['CREATE_STENCIL',['../CSampleFromVoxels_8h.html#af44e910a01a2e0dcdac8bab426ed3365',1,'CSampleFromVoxels.h']]],
  ['create_5ftileentry_17',['CREATE_TILEENTRY',['../CNanoVDB_8h.html#a9e6f602fbea00a179a9c49ea97dfeebd',1,'CNanoVDB.h']]],
  ['cudacheck_18',['cudaCheck',['../CudaDeviceBuffer_8h.html#a93e6bf7c8996268aa9a2740d6f1de76d',1,'CudaDeviceBuffer.h']]]
];
